<html xmlns="http://www.w3.org/1999/xhtml"
      xmlns:py="http://genshi.edgewall.org/"
      xmlns:xi="http://www.w3.org/2001/XInclude"
      py:strip="">
    <div>
        ${ajaxform._ajaxform_display(value=value)}
    </div>
    <script>
        jQuery('#${ajaxform_id}').find('form').ajaxForm({target:jQuery('#${ajaxform_id}'),
                                                            url:'${ajaxform_action}',
                                                    beforeSubmit:function(arr, form, options) {
                                                        jQuery('#${ajaxform_id}').html('<img class="spinner_icon" src="${ajaxform_spinner.link}"/>');
                                                    }
        });
    </script>
</html>

